# 2022-03-25 - GaugeAdder

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This first version has been deprecated. Here is the [current version](../../20230519-gauge-adder-v4/).

Deployment of the `GaugeAdder`, a helper contract which helps prevent some forms of improper configuration on the `GaugeController`.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`GaugeAdder` artifact](./artifact/GaugeAdder.json)
